pub struct MarkdownNotesDocument { /* private fields */ }Expand description
A parsed Markdown notes file that can be updated without rewriting headings.
Implementations
Sourceimpl MarkdownNotesDocument
impl MarkdownNotesDocument
Sourcepub fn read(
path: &Path,
total_logical_slides: usize,
) -> Result<Self, SidecarError>
pub fn read( path: &Path, total_logical_slides: usize, ) -> Result<Self, SidecarError>
Read and parse a Markdown notes file.
Sourcepub fn notes_by_slide(&self) -> HashMap<usize, String>
pub fn notes_by_slide(&self) -> HashMap<usize, String>
Return notes keyed by zero-based logical slide index.
Sourcepub fn write_notes(
&self,
notes: &HashMap<usize, String>,
) -> Result<(), SidecarError>
pub fn write_notes( &self, notes: &HashMap<usize, String>, ) -> Result<(), SidecarError>
Write updated notes back to the original Markdown file.